@@ -1,5 +1,5 @@
 package DateTime::TimeZone::Local::Win32;
-$DateTime::TimeZone::Local::Win32::VERSION = '1.90';
+$DateTime::TimeZone::Local::Win32::VERSION = '1.91';
 use 5.006;
 
 use strict;
@@ -57,14 +57,14 @@ sub EnvVars { return 'TZ' }
         'Cen. Australia'                  => 'Australia/Adelaide',
         'Cen. Australia Standard Time'    => 'Australia/Adelaide',
         'Central'                         => 'America/Chicago',
-        'Central America Standard Time'   => 'America/Regina',
+        'Central America Standard Time'   => 'America/Tegucigalpa',
         'Central Asia'                    => 'Asia/Almaty',
         'Central Asia Standard Time'      => 'Asia/Almaty',
         'Central Brazilian Standard Time' => 'America/Cuiaba',
         'Central Europe'                  => 'Europe/Prague',
         'Central Europe Standard Time'    => 'Europe/Prague',
         'Central European'                => 'Europe/Belgrade',
-        'Central European Standard Time'  => 'Europe/Belgrade',
+        'Central European Standard Time'  => 'Europe/Warsaw',
         'Central Pacific'                 => 'Pacific/Guadalcanal',
         'Central Pacific Standard Time'   => 'Pacific/Guadalcanal',
         'Central Standard Time'           => 'America/Chicago',
@@ -80,7 +80,7 @@ sub EnvVars { return 'TZ' }
         'E. Australia'                    => 'Australia/Brisbane',
         'E. Australia Standard Time'      => 'Australia/Brisbane',
         'E. Europe'                       => 'Europe/Helsinki',
-        'E. Europe Standard Time'         => 'Europe/Helsinki',
+        'E. Europe Standard Time'         => 'Europe/Chisinau',
         'E. South America'                => 'America/Sao_Paulo',
         'E. South America Standard Time'  => 'America/Sao_Paulo',
         'Easter Island Standard Time'     => 'Pacific/Easter',
@@ -109,7 +109,7 @@ sub EnvVars { return 'TZ' }
         'Hawaiian'                        => 'Pacific/Honolulu',
         'Hawaiian Standard Time'          => 'Pacific/Honolulu',
         'India'                           => 'Asia/Calcutta',
-        'India Standard Time'             => 'Asia/Calcutta',
+        'India Standard Time'             => 'Asia/Kolkata',
         'Iran'                            => 'Asia/Tehran',
         'Iran Standard Time'              => 'Asia/Tehran',
         'Israel'                          => 'Asia/Jerusalem',
@@ -219,7 +219,7 @@ sub EnvVars { return 'TZ' }
         'W. Mongolia Standard Time'       => 'Asia/Hovd',
         'Warsaw'                          => 'Europe/Warsaw',
         'West Asia'                       => 'Asia/Karachi',
-        'West Asia Standard Time'         => 'Asia/Karachi',
+        'West Asia Standard Time'         => 'Asia/Tashkent',
         'West Bank Standard Time'         => 'Asia/Gaza',
         'West Pacific'                    => 'Pacific/Guam',
         'West Pacific Standard Time'      => 'Pacific/Guam',
@@ -313,7 +313,7 @@ DateTime::TimeZone::Local::Win32 - Determine the local system's time zone on Win
 
 =head1 VERSION
 
-version 1.90
+version 1.91
 
 =head1 SYNOPSIS
 
